#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# project web page : http://scorpioncity.com/sokoban.html
# source           : http://scorpioncity.com/sokoban/syasokoban-2.0.tar.gz

# Package name
NAME="syasokoban"
# Package version
VERSION="2.0"
# Source code URL
SOURCE="http://scorpioncity.com/sokoban/syasokoban-2.0.tar.gz"
# Files that should be placed in /usr/doc/package-version/
DOCS="README.txt"
# ./configure options
CONFIGOPTIONS="--prefix=/usr"

CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="i486"
CPU="i686"
BUILD="46.2"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$NAME: syasokoban is an implementation of the popular Sokoban puzzle game
$NAME:
$NAME: Still Yet Another Sokoban is an implementation of the popular
$NAME: Sokoban puzzle game. The goal is to push the crates onto the
$NAME: designated squares without getting stuck.
$NAME:
$NAME:
$NAME:
$NAME:
$NAME:
$NAME:
END

# Create the desktop entry
mkdir -p $PKG/usr/share/applications
cat > $PKG/usr/share/applications/$NAME.desktop <<EOF
[Desktop Entry]
Encoding=UTF-8
Name=Still Yet Another Sokoban
Exec=syasokoban
Terminal=false
Type=Application
Categories=Game;LogicGame;
Icon=SYASokoban
EOF

# Check to see if source is present. If it's not, download it
rm -rf $NAME-$VERSION
if [ -f $NAME-$VERSION.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

# Unpack source
tar xvzf $NAME-$VERSION.tar.gz

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# 'heavy' computer: 6 build-jobs at once
#
#numjobs='-j6'
#
# 'light' computer: 2 build-jobs at once
#
numjobs='-j2'

# We need to make some changes to the source and Makefile before building
cd $NAME-$VERSION
sed -i -e "s,-ansi -Wall -I/usr/local/include,-O2 -march=i486 -mtune=i686 -ansi -Wall -I/usr/include," Makefile
sed -i -e "s,data/sokoban/sokoban_icon.bmp,/usr/share/syasokoban/data/sokoban/sokoban_icon.bmp," src/Main.cpp
sed -i -e "s,data/,/usr/share/syasokoban/data/," src/djDesktop.cpp
make $numjobs

# Install on temporary directory
mkdir -p $PKG/usr/bin
cp -a syasokoban $PKG/usr/bin
mkdir -p $PKG/usr/share/$NAME
cp -a data $PKG/usr/share/$NAME

mkdir -p $PKG/usr/share/icons/hicolor/48x48/apps/
cp -a data/sokoban/SYASokoban.png $PKG/usr/share/icons/hicolor/48x48/apps/

# Strip binaries
cd $PKG
find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Copy Docs
mkdir -p $PKG/usr/doc/$NAME-$VERSION
cd $CWD/$NAME-$VERSION
cp -a $DOCS $PKG/usr/doc/$NAME-$VERSION

# Add the build-file in the package
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Make the package
makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum and dependencies files
cd $CWD/
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5
requiredbuilder -z $PKG > $NAME-$VERSION-$ARCH-$BUILD.dep

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME-$VERSION
rm -rf $PKG
